Adapters
========

Adapters convert external data formats (pandas DataFrames, etc.) into the
canonical DataArray formats used by this library. They also attach metadata
as coordinates and set standard attributes.

.. toctree::
   :maxdepth: 2

   from_dataframe
